
import * as fs from 'fs/promises';

import { QuestionNode } from "./node-types/question";
import { ClaimNode } from './node-types/claim';
import { EvidenceNode } from './node-types/evidence';
import { SourceNode } from './node-types/source';

export class Compiler {

    public static nodes = [
        ClaimNode,
        EvidenceNode,
        QuestionNode,
        SourceNode
    ];

    public static getNodeType(name: string) {
        for (const nodeType of Compiler.nodes) {
            if (nodeType.TYPE_PATTERN.test(name)) return nodeType;
        }
        throw new Error(`File name does not match any known node type \n - ${name}`);
    }


    static async loadNodes(directory: string) {
        console.log('Loading nodes...');
        const nodes = [];
        const files = await fs.readdir(directory);
        for (const file of files) try {
            const NodeType = Compiler.getNodeType(file);
            const node = NodeType.load(file, "");
            nodes.push(node);
            console.log(`Loaded ${NodeType.TYPE} node "${node.name}"`);
        } catch (err) {
            console.error(err.message);
        }
        return nodes;
    }


}

const graphPath = "./example_graph";
Compiler.loadNodes(graphPath);